@@ -18,9 +18,6 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
 
 import gettext
 import os
@@ -29,32 +26,32 @@ import subprocess
 import sys
 import time
 import unittest
+from importlib import reload
 
 from duplicity import backend
 from duplicity import config
 from duplicity import log
 from duplicity import util
 
-# util.start_debugger()
+gettext.install("duplicity", names=["ngettext"])
 
-if sys.version_info.major >= 3:
-    gettext.install(u'duplicity', names=[u'ngettext'])
-else:
-    gettext.install(u'duplicity', names=[u'ngettext'], unicode=True)  # pylint: disable=unexpected-keyword-arg
+log.setup()
+util.start_debugger()
 
 _testing_dir = os.path.dirname(os.path.abspath(__file__))
 _top_dir = os.path.dirname(_testing_dir)
-_overrides_dir = os.path.join(_testing_dir, u'overrides')
-_bin_dir = os.path.join(_testing_dir, u'overrides', u'bin')
+_overrides_dir = os.path.join(_testing_dir, "overrides")
+_bin_dir = os.path.join(_testing_dir, "overrides", "bin")
 
-if platform.system().startswith(u'Darwin'):
+if platform.system().startswith("Darwin"):
     # Use temp space TMPDIR or from getconf, never /tmp
-    _runtest_dir = (os.environ.get(u"TMPDIR", None) or
-                    subprocess.check_output([u'getconf', u'DARWIN_USER_TEMP_DIR']))
-    _runtest_dir = os.fsdecode(_runtest_dir).rstrip().rstrip(u'/')
+    _runtest_dir = os.environ.get("TMPDIR", None) or subprocess.check_output(["getconf", "DARWIN_USER_TEMP_DIR"])
+    _runtest_dir = os.fsdecode(_runtest_dir).rstrip().rstrip("/")
+    if not os.path.exists(_runtest_dir):
+        os.makedirs(_runtest_dir)
 else:
     # be a little more flexible
-    _runtest_dir = os.getenv(u'TMPDIR', False) or os.getenv(u'TEMP', False) or u'/tmp'
+    _runtest_dir = os.getenv("TMPDIR", False) or os.getenv("TEMP", False) or "/tmp"
 
 if not os.path.exists(_runtest_dir):
     os.makedirs(_runtest_dir)
@@ -63,57 +60,52 @@ if not os.path.exists(_runtest_dir):
 sys.path = [_overrides_dir, _top_dir, _bin_dir] + sys.path
 
 # Also set PYTHONPATH for any subprocesses
-os.environ[u'PYTHONPATH'] = _overrides_dir + u":" + _top_dir + u":" + os.environ.get(u'PYTHONPATH', u'')
+os.environ["PYTHONPATH"] = f"{_overrides_dir}:{_top_dir}:{os.environ.get('PYTHONPATH', '')}"
 
 # And PATH for any subprocesses
-os.environ[u'PATH'] = _bin_dir + u":" + os.environ.get(u'PATH', u'')
+os.environ["PATH"] = f"{_bin_dir}:{os.environ.get('PATH', '')}"
 
 # Now set some variables that help standardize test behavior
-os.environ[u'LANG'] = u''
-os.environ[u'GNUPGHOME'] = os.path.join(_testing_dir, u'gnupg')
+os.environ["LANG"] = ""
+os.environ["GNUPGHOME"] = os.path.join(_testing_dir, "gnupg")
 
 # bzr does not honor perms so fix the perms and avoid annoying error
-os.system(u"chmod 700 %s" % os.path.join(_testing_dir, u'gnupg'))
+os.system(f"chmod 700 {os.path.join(_testing_dir, 'gnupg')}")
 
 # Standardize time
-os.environ[u'TZ'] = u'US/Central'
+os.environ["TZ"] = "US/Central"
 time.tzset()
 
-# TODO: find place in setup.py to do this
-# fix shebangs in _bin_dir to be current python
-if sys.version_info.major == 2:
-    files = os.listdir(_bin_dir)
-    for file in files:
-        print(u"converting %s to python2" % file, file=sys.stderr)
-        with open(os.path.join(_bin_dir, file), u"r") as f:
-            p2 = f.read().replace(u"python3", u"python")
-        with open(os.path.join(_bin_dir, file), u"w") as f:
-            p2 = f.write(p2)
-
 
 class DuplicityTestCase(unittest.TestCase):
-
-    sign_key = u'839E6A2856538CCF'
-    sign_passphrase = u'test'
-    encrypt_key1 = u'839E6A2856538CCF'
-    encrypt_key2 = u'453005CE9B736B2A'
+    sign_key = "839E6A2856538CCF"
+    sign_passphrase = "test"
+    encrypt_key1 = "839E6A2856538CCF"
+    encrypt_key2 = "453005CE9B736B2A"
 
     def setUp(self):
-        super(DuplicityTestCase, self).setUp()
+        super().setUp()
         self.savedEnviron = {}
         self.savedConfig = {}
 
         log.setup()
         log.setverbosity(log.WARNING)
-        self.set_config(u'print_statistics', 0)
+        self.set_config("print_statistics", 0)
         backend.import_backends()
 
         self.remove_testfiles()
         self.unpack_testfiles()
 
+        self.set_environ("TZ", "UTC")
+        time.tzset()
+        assert time.tzname[0] == "UTC", f"{time.tzname[0]} should be 'UTC'"
+
         # Have all file references in tests relative to our runtest dir
         os.chdir(_runtest_dir)
 
+        # reimport duplicity.config in case it changed
+        reload(config)
+
     def tearDown(self):
         for key in self.savedEnviron:
             self._update_env(key, self.savedEnviron[key])
@@ -121,18 +113,20 @@ class DuplicityTestCase(unittest.TestCase):
         for key in self.savedConfig:
             setattr(config, key, self.savedConfig[key])
 
+        time.tzset()
+
         self.remove_testfiles()
 
         os.chdir(_testing_dir)
-        super(DuplicityTestCase, self).tearDown()
+        super().tearDown()
 
     def unpack_testfiles(self):
-        assert not os.system(u"rm -rf {0}/testfiles".format(_runtest_dir))
-        assert not os.system(u"tar xzf {0}/testfiles.tar.gz -C {1} > /dev/null 2>&1".format(_testing_dir, _runtest_dir))
-        assert not os.system(u"mkdir {0}/testfiles/output {0}/testfiles/cache".format(_runtest_dir))
+        assert not os.system(f"rm -rf {_runtest_dir}/testfiles")
+        assert not os.system(f"tar xzf {_testing_dir}/testfiles.tar.gz -C {_runtest_dir} > /dev/null 2>&1")
+        assert not os.system(f"mkdir {_runtest_dir}/testfiles/output {_runtest_dir}/testfiles/cache")
 
     def remove_testfiles(self):
-        assert not os.system(u"rm -rf {0}/testfiles".format(_runtest_dir))
+        assert not os.system(f"rm -rf {_runtest_dir}/testfiles")
 
     def _update_env(self, key, value):
         if value is not None:
